"""Templates -- Python templating library with templates included.

:copyright: (c) 2018 by Grant Jenks.
:license: Apache 2.0, see LICENSE for more details.

"""

from .base import Template
from .html import HTMLTemplate, Tag

__title__ = 'templates'
__version__ = '0.0.3'
__build__ = 0x000003
__author__ = 'Grant Jenks'
__license__ = 'Apache 2.0'
__copyright__ = '2018, Grant Jenks'
